@@ -3,15 +3,15 @@
 # of species in (metastable) equilibrium
 
 equilibrate <- function(aout, balance=NULL, loga.balance=NULL, 
-  ispecies=1:length(aout$values), normalize=FALSE, as.residue=FALSE) {
+  ispecies=1:length(aout$values), normalize=FALSE, as.residue=FALSE,
+  method=c("boltzmann", "reaction")) {
   ### set up calculation of equilibrium activities of species from the affinities 
   ### of their formation reactions from basis species at known activities
   ### split from diagram() 20120925 jmd
   ## number of possible species
   nspecies <- length(aout$values)
   ## get the balancing coefficients
-  balance <- balance(aout, balance)
-  n.balance <- balance$n
+  n.balance <- balance(aout, balance)
   ## take selected species in 'ispecies'
   if(length(ispecies)==0) stop("the length of ispecies is zero")
   # take out species that have NA affinities
@@ -27,17 +27,15 @@ equilibrate <- function(aout, balance=NULL, loga.balance=NULL,
   ## number of species that are left
   nspecies <- length(aout$values)
   ## say what the balancing coefficients are
-  if(length(n.balance) < 100) msgout(paste("equilibrate: balancing coefficients are", c2s(n.balance), "\n"))
+  if(length(n.balance) < 100) msgout(paste("equilibrate: n.balance is", c2s(n.balance), "\n"))
   ## logarithm of total activity of the balance
-  if(is.numeric(loga.balance)) 
-    msgout(paste("equilibrate: logarithm of total", balance$description, "(from loga.balance) is", loga.balance, "\n"))
-  else {
+  if(is.null(loga.balance)) {
     # sum up the activities, then take absolute value
     # in case n.balance is negative
     sumact <- abs(sum(10^aout$species$logact * n.balance))
     loga.balance <- log10(sumact)
-    msgout(paste("equilibrate: logarithm of total", balance$description, "is", loga.balance, "\n"))
   }
+  msgout(paste0("equilibrate: loga.balance is ", loga.balance, "\n"))
   ## normalize -- normalize the molar formula by the balance coefficients
   m.balance <- n.balance
   isprotein <- grepl("_", as.character(aout$species$name))
@@ -54,9 +52,14 @@ equilibrate <- function(aout, balance=NULL, loga.balance=NULL,
     # and normalize the value by the nor-molar ratio
     (aout$values[[i]] + aout$species$logact[i]) / m.balance[i] 
   })
-  ## compute the equilibrium activities of species
-  if(all(n.balance==1)) loga.equil <- equil.boltzmann(Astar, n.balance, loga.balance)
-  else loga.equil <- equil.reaction(Astar, n.balance, loga.balance)
+  ## chose a method and compute the equilibrium activities of species
+  if(missing(method)) {
+    if(all(n.balance==1)) method <- method[1]
+    else method <- method[2]
+  }
+  msgout(paste("equilibrate: using", method[1], "method\n"))
+  if(method[1]=="boltzmann") loga.equil <- equil.boltzmann(Astar, n.balance, loga.balance)
+  else if(method[1]=="reaction") loga.equil <- equil.reaction(Astar, n.balance, loga.balance)
   ## if we normalized the formulas, get back to activities to species
   if(normalize & !as.residue) {
     loga.equil <- lapply(1:nspecies, function(i) {
@@ -64,7 +67,8 @@ equilibrate <- function(aout, balance=NULL, loga.balance=NULL,
     })
   }
   ## put together the output
-  out <- c(aout, list(balance=balance, m.balance=m.balance, n.balance=n.balance, Astar=Astar, loga.equil=loga.equil))
+  out <- c(aout, list(balance=balance, m.balance=m.balance, n.balance=n.balance,
+    loga.balance=loga.balance, Astar=Astar, loga.equil=loga.equil))
   # done!
   return(out)
 }
@@ -82,7 +86,7 @@ equil.boltzmann <- function(Astar, n.balance, loga.balance) {
   # disadvantage:
   # 1) only works for per-residue reactions
   # 2) can create NaN logacts if the Astars are huge/small
-
+  if(any(n.balance!=1)) stop("won't run equil.boltzmann for balance <> 1")
   # initialize output object
   A <- Astar
   # remember the dimensions of elements of Astar (could be vector,matrix)
@@ -149,6 +153,11 @@ equil.reaction <- function(Astar, n.balance, loga.balance) {
   Abarrange <- function(i) {
     # starting guess of Abar (min/max) from range of Astar / n.balance
     Abar.range <- range(Astar[i, ] / n.balance)
+    # diff(Abar.range) can't be 0 (dlogadiff.dAbar becomes NaN)
+    if(diff(Abar.range)==0) {
+      Abar.range[1] <- Abar.range[1] - 0.1
+      Abar.range[2] <- Abar.range[2] + 0.1
+    }
     # the range of logadiff
     logadiff.min <- logadiff(Abar.range[1], i)
     logadiff.max <- logadiff(Abar.range[2], i)
@@ -160,7 +169,6 @@ equil.reaction <- function(Astar, n.balance, loga.balance) {
     # if one of them is infinite we might have a chance
     if(is.infinite(logadiff.min)) {
       # decrease the Abar range by increasing the minimum
-      # the 0.99 is necessary at least for the residue=FALSE plot in protactiv.Rnw; 0.9 isn't enough!
       Abar.range[1] <- Abar.range[1] + 0.99 * diff(Abar.range)
       logadiff.min <- logadiff(Abar.range[1], i)
       if(is.infinite(logadiff.min)) stop("FIXME: the second initial guess for Abar.min failed")
@@ -171,28 +179,24 @@ equil.reaction <- function(Astar, n.balance, loga.balance) {
       logadiff.max <- logadiff(Abar.range[2], i)
       if(is.infinite(logadiff.max)) stop("FIXME: the second initial guess for Abar.max failed")
     }
-    # the change of logadiff with Abar
-    # it's a weighted mean of the n.balance
-    dlogadiff.dAbar <- (logadiff.max - logadiff.min) / diff(Abar.range)
-    # change Abar to center logadiff (min/max) on zero
-    logadiff.mean <- mean(c(logadiff.min, logadiff.max))
-    Abar.range <- Abar.range - logadiff.mean / dlogadiff.dAbar
-    # one iteration is enough for the examples in the package
-    # but there might be a case where the range of logadiff doesn't cross zero
-    # (e.g. for the carboxylic acid example in revisit.Rd)
-    logadiff.min <- logadiff(Abar.range[1], i)
-    logadiff.max <- logadiff(Abar.range[2], i)
-    if(logadiff.min > 0 | logadiff.max < 0) {
-      # do again what we did above
+    iter <- 0
+    while(logadiff.min > 0 | logadiff.max < 0) {
+      # the change of logadiff with Abar
+      # it's a weighted mean of the n.balance
       dlogadiff.dAbar <- (logadiff.max - logadiff.min) / diff(Abar.range)
+      # change Abar to center logadiff (min/max) on zero
       logadiff.mean <- mean(c(logadiff.min, logadiff.max))
       Abar.range <- Abar.range - logadiff.mean / dlogadiff.dAbar
+      # one iteration is enough for the examples in the package
+      # but there might be a case where the range of logadiff doesn't cross zero
+      # (e.g. for the carboxylic acid example in revisit.Rd)
       logadiff.min <- logadiff(Abar.range[1], i)
       logadiff.max <- logadiff(Abar.range[2], i)
-      if(logadiff.min > 0 | logadiff.max < 0) {
-        stop("FIXME: make this function (Abarrange() in equil.reaction()) 
-          iterate again to find a range of Abar such that the differences in 
-          logarithm of activity of the conserved component cross zero")
+      iter <- 1
+      if(iter > 5) {
+        stop("FIXME: we seem to be stuck! This function (Abarrange() in
+          equil.reaction()) can't find a range of Abar such that the differences
+          in logarithm of activity of the conserved component cross zero")
       }
     }
     return(Abar.range)
@@ -249,21 +253,16 @@ balance <- function(aout, balance=NULL) {
   if(is.numeric(balance[1])) {
     # a numeric vector
     n.balance <- rep(balance, length.out=length(aout$values))
-    if(all(n.balance==1)) msgout("balance: coefficients are unity\n")
-    # use 'balance' below as a name
-    if(all(n.balance==1)) balance.description <- "moles of species"
-    else balance <- "moles of user-specified coefficients"
+    msgout("balance: from numeric argument value\n")
   } else {
     # "length" for balancing on protein length
     if(identical(balance, "length")) {
       if(!all(isprotein)) stop("length was the requested balance, but some species are not proteins")
       n.balance <- protein.length(aout$species$name)
-      balance.description <- "protein length"
-      msgout(paste("balance: coefficients are", balance.description, "\n"))
+      msgout("balance: from protein length\n")
     } else if(identical(balance, "volume")) {
       n.balance <- info(aout$species$ispecies, check.it=FALSE)$V
-      balance.description <- "volume"
-      msgout(paste("balance: coefficients are", balance.description, "\n"))
+      msgout("balance: from volume")
     } else {
       # is the balance the name of a basis species?
       if(length(ibalance)==0) {
@@ -272,13 +271,12 @@ balance <- function(aout, balance=NULL) {
       }
       # the name of the basis species (need this if we got ibalance which which.balance, above)
       balance <- colnames(aout$species)[ibalance[1]]
-      balance.description <- paste("moles of", balance)
-      msgout(paste("balance: coefficients are", balance.description, "in formation reactions\n"))
+      msgout(paste("balance: from moles of", balance, "in formation reactions\n"))
       # the balance vector
       n.balance <- aout$species[, ibalance[1]]
       # we check if that all formation reactions contain this basis species
       if(any(n.balance==0)) stop("some species have no ", balance, " in the formation reaction")
     }
   }
-  return(list(n=n.balance, description=balance.description))
+  return(n.balance)
 }
